无敌破坏王 (豆瓣)
Description: 无敌破坏王电影简介和剧情介绍,无敌破坏王影评、图片、预告片、影讯、论坛、在线购票
Keywords: 无敌破坏王,Wreck-It Ralph,无敌破坏王影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.185豆瓣电影Top250

# 无敌破坏王 Wreck-It Ralph (2012)

导演: 瑞奇·摩尔
编剧: 菲尔·约翰斯顿 / 珍妮弗·李 / 瑞奇·摩尔 / 吉姆·里尔顿 / 约翰·C·赖利 / 山姆·J·莱文 / 贾里德·斯特恩
主演: 约翰·C·赖利 / 萨拉·西尔弗曼 / 杰克·麦克布瑞尔 / 简·林奇 / 艾伦·图代克 / 敏迪·卡灵 / 乔·洛·特鲁格里奥 / 艾德·奥尼尔 / 丹尼斯·海斯伯特 / 伊迪·麦克勒格 / 雷蒙德·S·佩尔西 / 杰斯·哈梅尔 / 瑞秋·哈里斯 / 斯盖拉·阿斯丁 / 亚当·卡罗拉 / 霍拉提奥·桑斯 / 莫里斯·拉马奇 / 斯戴芬妮·斯考特 / 约翰·迪·马吉欧 / 瑞奇·摩尔 / 凯蒂·洛斯 / 贾米·埃曼 / 乔西·特立尼达 / 辛贝·沃克 / 塔克·吉莫尔 / 布兰登·斯考特 / 蒂姆·梅尔滕斯 / 凯文·迪特斯 / 杰洛·里佛斯 / 马丁·贾维斯 / 布莱恩·克辛格 / 罗杰·克莱格·史密斯 / 菲尔·约翰斯顿 / 鲁本·兰登 / 凯尔·赫伯特 / 洁米·斯贝勒·罗伯茨 / 尼克·格里姆肖
类型: 喜剧 / 动画 / 奇幻 / 冒险
制片国家/地区: 美国
语言: 英语
上映日期: 2012-11-06(中国大陆) / 2012-11-02(美国)
片长: 101分钟
又名: 破坏王拉尔夫 / 破坏王大冒险
IMDb: tt1772341
豆瓣评分
引用
8.7
509047人评价
5星
48.2%
4星
40.7%
3星
10.4%
2星
0.6%
1星
0.1%
好于 97% 动画片
好于 98% 喜剧片
想看 看过
评价:
推荐

## 无敌破坏王的剧情简介 · · · · · ·

无敌破坏王（约翰·C·赖利 John C. Reilly 配音）生活在一个80年代出品的低精度游戏中。他的设定身份是一个反派，每天的生活就是在游戏《快手阿修》中大搞破坏，其后由玩家操作的英雄人物快手阿修（杰克·麦克布瑞尔 Jack McBrayer 配音） 会及时赶到进行修补，赢得奖牌，包揽一切荣耀。身为反派，破坏王厌倦了自己的生活，眼看阿修被胜利者的光环围绕，自己却日复一日在无趣中过活，他终于决定改变。单纯的他以为只要自己也能得到一枚奖牌，就可以摆脱反派的身份，于是某日在游戏厅歇业后，破坏王偷偷离开了自己的游戏，前去闯荡其他电子游戏的世界。
在途中，破坏王结识了来自《英雄使命》的冷酷队长（简·林奇 Jane Lynch 配音）和来自90年代糖果赛车游戏《甜蜜冲刺》的小女孩云妮（萨拉·丝沃曼 Sarah Silverman 配音）。后者梦想着能上场比... (展开全部) 无敌破坏王（约翰·C·赖利 John C. Reilly 配音）生活在一个80年代出品的低精度游戏中。他的设定身份是一个反派，每天的生活就是在游戏《快手阿修》中大搞破坏，其后由玩家操作的英雄人物快手阿修（杰克·麦克布瑞尔 Jack McBrayer 配音） 会及时赶到进行修补，赢得奖牌，包揽一切荣耀。身为反派，破坏王厌倦了自己的生活，眼看阿修被胜利者的光环围绕，自己却日复一日在无趣中过活，他终于决定改变。单纯的他以为只要自己也能得到一枚奖牌，就可以摆脱反派的身份，于是某日在游戏厅歇业后，破坏王偷偷离开了自己的游戏，前去闯荡其他电子游戏的世界。
在途中，破坏王结识了来自《英雄使命》的冷酷队长（简·林奇 Jane Lynch 配音）和来自90年代糖果赛车游戏《甜蜜冲刺》的小女孩云妮（萨拉·丝沃曼 Sarah Silverman 配音）。后者梦想着能上场比赛，但其身份也不允许她梦想成真。破坏王所属的游戏《快手阿修》由于失去了他被认定为系统错误，如不尽快返回，则游戏就会被永久删除；而《甜蜜冲刺》的游戏世界则在悄悄酝酿着一场巨大的、威胁到整个游戏世界的阴谋。这也许是无敌破坏王实现梦想的机会，但也可能是一条不归路…… 他可以扭转乾坤，成为一名真正的英雄吗？ ©豆瓣

## 无敌破坏王的演职员 · · · · · · ( 全部 55 )

- 瑞奇·摩尔 导演
- 约翰·C·赖利 配 破坏王拉尔夫 Ralph
- 萨拉·西尔弗曼 配 云妮洛普 Vanellope
- 杰克·麦克布瑞尔 配 快手阿修 Felix
- 简·林奇 配 卡尔霍恩军士 Calhoun
- 艾伦·图代克 配 糖果国王 King Candy

## 无敌破坏王的视频和图片 · · · · · · ( 预告片24 | 添加视频评论 | 图片1027 · 添加 )

## 无敌破坏王的获奖情况 · · · · · · ( 全部 )

- 第85届奥斯卡金像奖
- 最佳动画长片(提名)
- 瑞奇·摩尔

- 第70届金球奖
- 电影类 最佳动画长片(提名)

- 第40届动画安妮奖
- 最佳动画长片

## 喜欢这部电影的人也喜欢 · · · · · ·

  玩具总动员

  大闹天宫

  怪兽电力公司

  天空之城

  幽灵公主

  神偷奶爸

  哈尔的移动城堡

  冰川时代

  美食总动员

  超人总动员

我要写短评

## 无敌破坏王的短评 · · · · · · ( 全部 105159 条 )

热门 / 最新 / 好友

### 2530 有用 江倍恒 看过 2012-10-18 19:26:54

迪士尼的华丽逆袭！ 当拉尔夫落向可乐山，耳边响起坏蛋宣言的时候，即使我已经猜到了结局依然被感动到一塌糊涂……

### 1662 有用 白发生 看过 2012-11-08 16:15:28

即便今年的动画电影整体水平偏低，也不至于把这样一部作品推上神坛。

### 577 有用 同志亦凡人中文站 看过 2012-11-06 21:46:20

正太把御姐，罗莉泡猛男——这真是一个三观尽毁的电玩世界！

### 1603 有用 psycho DC 看过 2012-11-06 22:36:06

给我一瓶可乐 + 一包曼妥思 我能拯救全世界！！！！

### 325 有用 大奇特(Grinch) 看过 2012-11-06 15:34:01

蜀黍和萝莉、御姐和正太的逆天组合，和《复联》《林中小屋》一样，以“穿越”串起主轴，却没有前者的一锅乱炖，而是毫无违和感。以“反英雄”主角的消极情绪，一路升温来找回正能量。倘若你曾是8位机或游戏厅的玩家，必定能够旧梦重温、重拾童趣！

> 更多短评 105159条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 无敌破坏王的影评 · · · · · · ( 全部 700 条 )

热门 / 最新 / 好友
宋小卡 2012-11-06 21:32:13

## 八一八《无敌破坏王》里都有哪些大明星

《无敌破坏王》最高级的地方就在于，几角旮旯里都埋着“小霸王其乐无穷啊”时代的熟人，迪士尼自称受到了皮克斯《玩具总动员》的启发，与全球游戏厂家谈了一个巨大的合作，终于让不同公司的游戏人物破除了门户之见，集结到了同一部电影里。《玩具总动员》对于中国观众来说应该... (展开)
1656 78 237回应 收起
嘤嘤嘤的树树 2012-11-09 13:40:58

## 好片子！谈点关于故事的干货吧

要不是因为手上赠卷太多了，我是不会去电影院看《无敌破坏王》的，谁知道看完以后，十分欣喜地发现，《无敌破坏王》无疑是近几年内动画电影的佳作。反正动画编剧这个事我还算熟悉，就主要说一下故事的优点吧。 　　1. 角度巧妙的世界观设定 　　作为一部动画电影，在谈论剧本... (展开)
1406 67 105回应 收起
舞台上的观众 2012-11-08 00:05:58

## 英雄的嗝屁

这篇影评可能有剧透

这些年来的春晚，最令我全身上下暴涨鸡皮疙瘩手足无措难忍厕意的，必然是蔡明的小品，并不是因为演员难看或演技差劲，而是他们最后一定要来个感人场景，等几个段子说完了，凄婉优美的钢琴音乐一起，蔡明同志就要眼含热泪地用咏叹调高呼大爱，从喜剧女星直接转型赈灾女主持人，... (展开)
382 44 56回应 收起
唐书钰 2012-11-10 18:13:24

## 他奋斗了一整部电影就是为了站在你面前

近两年频繁出现的复古元素确实很讨喜，只是对于吾辈童年鲜少玩游戏机的小孩来说，《无敌破坏王》的直观吸引力确实少了很多，这个动画并没有在怀念层面真的吸引到我。但不可否认这依旧是一部非常好看的电影。 任何根据画面色彩、情节设置、人物性格等各个方面的狗腿的赞美我看... (展开)
200 3 21回应 收起
starlucifer 2013-02-26 06:11:08

## 吃货扫盲贴： 都有哪些糕点糖果的大明星在Sugar Rush里面出现？

据说在美国牙医之所以那么吃香赚钱，很大的一个原因就是美国佬太爱吃甜食了~ 超市里面一排一排的饼干糖果货架，糕点铺里各式各样的手工巧克力与纸杯蛋糕，餐厅菜单里最后两页永远是琳琅满目的餐后甜品，甚至酒吧里都是各种炫目的又甜又烈的鸡尾酒。也难怪美国到处是大片大片的... (展开)
145 1 9回应 收起
XY 2012-11-10 15:02:33

## 扫盲贴：who is the bad guy?

只说那张著名的“反派互助协会”里出现的，只说能看出来的（好像是废话） 克莱德（Clyde）：互助协会的东道主/主席，坐在破坏王正对面。这是所有bad guy中最老的家伙，来自南梦宫（Namco）的《吃豆人》（Pac-Man），可爱的小幽灵，是整天追着Pac-man要吃它的bad guy。《吃豆人... (展开)
76 7 9回应 收起
Still Water 2012-11-06 15:50:07

## 皮克斯外衣下的迪士尼

这篇影评可能有剧透

IMAX厅拿来放这个普通3D的片子，似乎偏暗了些。 剧本，音乐，视效……相当出色，但其实可以更好。 ——细节相当出色，比如那些动起来像定格动画的小人，他们笨拙老式的动作和高清CG化之后的形象间的对比简直是纯天然的笑料，尤其是老金拉着拉杆箱上楼梯的时候。还有蛋糕溅到... (展开)
45 15 12回应 收起
碎碎 2012-11-08 12:28:47

## 你看那张高清的脸！-含剧透

这篇影评可能有剧透

女配之所以是游戏史上最悲惨背景的女人，一定是因为机器飞蛾吃了新郎之后变成新郎遭到新娘亲手扼杀！！！被剪掉了，太悲剧了。一定是 昨天在安贞UME看了这部电影，令人怀念的槽点都和自己的好朋友分享，实在是一件快乐的事情。 首先，这部电影让大家不停地提起玩具总动员，... (展开)
48 3 11回应 收起
爱吃馒头的宝宝 2017-06-03 15:12:09

## 让人想要回去回忆童年

这篇影评可能有剧透

坏王厌倦一直在游戏世界里做反派，于是他决心离开自己的游戏去闯荡别的电玩世界，旅途中他误闯多个截然不同的游戏世界，遇到严酷的士兵队长、刀子嘴豆腐心的倔强小女孩云妮露，展开一段精彩的反派逆袭。 这个片子比较适合爱着怀旧游戏的人们看，剧情简单，一般动画电影的感人搞... (展开)
29 1 0回应 收起
duckducker 2012-11-03 10:52:54

## I'm bad, but that's good. I will never be good, but that's not bad

wreck-it, fix-it. bad guy, hero...WRECK-IT RALPH证明了这些概念的流动性，我们因此跳脱了对video-game cartoon的第一印象。 它是深刻的。 我们能脱离社会赋予我们的角色吗？承担个人责任意味着什么？我们向别人证明自己的同时真正实现人生价值了吗？ 生活无尚的经历也许会让... (展开)
53 4 14回应 收起

> 更多影评 700篇

添加新讨论

## 讨论区 · · · · · ·

评分9.2? | 来自要去种果树的人 | 18 回应 | 2022-11-21 09:46:42
最后拉尔夫从火山重下那段致敬了什么电影啊 | 来自vaolik | 5 回应 | 2022-11-21 09:43:54
正片怎么样的 | 来自梨紫酱 |  | 2022-09-22 01:28:48
小萝莉与大叔，御姐与正太。太a了 日日的歌一出来... | 来自无法触碰。 |  | 2022-07-09 21:07:44
几个主角所在的游戏是虚构的吗？ | 来自逐梦演艺圈 |  | 2022-07-04 00:34:51

> 去这部影片的讨论区（全部133条）

## 关于《无敌破坏王》的问题 · · · · · · ( 全部4个 )

- 这部动画的制作成本有多少？ 1人回答
- 糖果国王有什么阴谋啊到底...？ 2人回答

> 全部4个问题

## 在哪儿看这部电影 · · · · · ·

- 芒果TV VIP免费观看
- 腾讯视频 VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【豆瓣高分动画长片】 (影志)
- {北美电影票房总排行} (荔枝超人)
- 2013【第85届奥斯卡】完整获奖/提名名单 (影志)
- 2012新电影（这些，可以期待） (桃桃林林)
- 2012 豆瓣电影【口碑榜】 (影志)

## 谁在看这部电影 · · · · · ·

- pupuさん
  4分钟前 看过
- 老虎莉莉
  9分钟前 想看
- 杨坚强
  10分钟前 看过

816987人看过 / 136292人想看

订阅无敌破坏王的评论:
feed: rss 2.0